# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/resource_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.spaceone/api/inventory/v1/resource_group.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"^\n\x08Resource\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12*\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x0f\n\x07keyword\x18\x03 \x01(\t\"\xda\x01\n\x1a\x43reateResourceGroupRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\tresources\x18\x02 \x03(\x0b\x32#.spaceone.api.inventory.v1.Resource\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\"\x8e\x02\n\x1aUpdateResourceGroupRequest\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\tresources\x18\x03 \x03(\x0b\x32#.spaceone.api.inventory.v1.Resource\x12(\n\x07options\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x17\n\x0frelease_project\x18\x0b \x01(\x08\x12\x12\n\nproject_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\"D\n\x14ResourceGroupRequest\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"U\n\x17GetResourceGroupRequest\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x90\x01\n\x12ResourceGroupQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x19\n\x11resource_group_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"\x80\x02\n\x11ResourceGroupInfo\x12\x19\n\x11resource_group_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\tresources\x18\x03 \x03(\x0b\x32#.spaceone.api.inventory.v1.Resource\x12(\n\x07options\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x07 \x01(\t\x12\x12\n\ncreated_at\x18\x08 \x01(\t\"h\n\x12ResourceGroupsInfo\x12=\n\x07results\x18\x01 \x03(\x0b\x32,.spaceone.api.inventory.v1.ResourceGroupInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"a\n\x16ResourceGroupStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xb8\x07\n\rResourceGroup\x12\x94\x01\n\x06\x63reate\x12\x35.spaceone.api.inventory.v1.CreateResourceGroupRequest\x1a,.spaceone.api.inventory.v1.ResourceGroupInfo\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/inventory/v1/resource-groups\x12\xa7\x01\n\x06update\x12\x35.spaceone.api.inventory.v1.UpdateResourceGroupRequest\x1a,.spaceone.api.inventory.v1.ResourceGroupInfo\"8\x82\xd3\xe4\x93\x02\x32\x1a\x30/inventory/v1/resource-group/{resource_group_id}\x12\x8b\x01\n\x06\x64\x65lete\x12/.spaceone.api.inventory.v1.ResourceGroupRequest\x1a\x16.google.protobuf.Empty\"8\x82\xd3\xe4\x93\x02\x32*0/inventory/v1/resource-group/{resource_group_id}\x12\xa1\x01\n\x03get\x12\x32.spaceone.api.inventory.v1.GetResourceGroupRequest\x1a,.spaceone.api.inventory.v1.ResourceGroupInfo\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/inventory/v1/resource-group/{resource_group_id}\x12\xb3\x01\n\x04list\x12-.spaceone.api.inventory.v1.ResourceGroupQuery\x1a-.spaceone.api.inventory.v1.ResourceGroupsInfo\"M\x82\xd3\xe4\x93\x02G\x12\x1d/inventory/v1/resource-groupsZ&\"$/inventory/v1/resource-groups/search\x12~\n\x04stat\x12\x31.spaceone.api.inventory.v1.ResourceGroupStatQuery\x1a\x17.google.protobuf.Struct\"*\x82\xd3\xe4\x93\x02$\"\"/inventory/v1/resource-groups/statb\x06proto3')



_RESOURCE = DESCRIPTOR.message_types_by_name['Resource']
_CREATERESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreateResourceGroupRequest']
_UPDATERESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['UpdateResourceGroupRequest']
_RESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['ResourceGroupRequest']
_GETRESOURCEGROUPREQUEST = DESCRIPTOR.message_types_by_name['GetResourceGroupRequest']
_RESOURCEGROUPQUERY = DESCRIPTOR.message_types_by_name['ResourceGroupQuery']
_RESOURCEGROUPINFO = DESCRIPTOR.message_types_by_name['ResourceGroupInfo']
_RESOURCEGROUPSINFO = DESCRIPTOR.message_types_by_name['ResourceGroupsInfo']
_RESOURCEGROUPSTATQUERY = DESCRIPTOR.message_types_by_name['ResourceGroupStatQuery']
Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCE,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.Resource)
  })
_sym_db.RegisterMessage(Resource)

CreateResourceGroupRequest = _reflection.GeneratedProtocolMessageType('CreateResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateResourceGroupRequest)
  })
_sym_db.RegisterMessage(CreateResourceGroupRequest)

UpdateResourceGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateResourceGroupRequest)
  })
_sym_db.RegisterMessage(UpdateResourceGroupRequest)

ResourceGroupRequest = _reflection.GeneratedProtocolMessageType('ResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceGroupRequest)
  })
_sym_db.RegisterMessage(ResourceGroupRequest)

GetResourceGroupRequest = _reflection.GeneratedProtocolMessageType('GetResourceGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESOURCEGROUPREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetResourceGroupRequest)
  })
_sym_db.RegisterMessage(GetResourceGroupRequest)

ResourceGroupQuery = _reflection.GeneratedProtocolMessageType('ResourceGroupQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceGroupQuery)
  })
_sym_db.RegisterMessage(ResourceGroupQuery)

ResourceGroupInfo = _reflection.GeneratedProtocolMessageType('ResourceGroupInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceGroupInfo)
  })
_sym_db.RegisterMessage(ResourceGroupInfo)

ResourceGroupsInfo = _reflection.GeneratedProtocolMessageType('ResourceGroupsInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPSINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceGroupsInfo)
  })
_sym_db.RegisterMessage(ResourceGroupsInfo)

ResourceGroupStatQuery = _reflection.GeneratedProtocolMessageType('ResourceGroupStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGROUPSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_group_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceGroupStatQuery)
  })
_sym_db.RegisterMessage(ResourceGroupStatQuery)

_RESOURCEGROUP = DESCRIPTOR.services_by_name['ResourceGroup']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCEGROUP.methods_by_name['create']._options = None
  _RESOURCEGROUP.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\037\"\035/inventory/v1/resource-groups'
  _RESOURCEGROUP.methods_by_name['update']._options = None
  _RESOURCEGROUP.methods_by_name['update']._serialized_options = b'\202\323\344\223\0022\0320/inventory/v1/resource-group/{resource_group_id}'
  _RESOURCEGROUP.methods_by_name['delete']._options = None
  _RESOURCEGROUP.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0022*0/inventory/v1/resource-group/{resource_group_id}'
  _RESOURCEGROUP.methods_by_name['get']._options = None
  _RESOURCEGROUP.methods_by_name['get']._serialized_options = b'\202\323\344\223\0022\0220/inventory/v1/resource-group/{resource_group_id}'
  _RESOURCEGROUP.methods_by_name['list']._options = None
  _RESOURCEGROUP.methods_by_name['list']._serialized_options = b'\202\323\344\223\002G\022\035/inventory/v1/resource-groupsZ&\"$/inventory/v1/resource-groups/search'
  _RESOURCEGROUP.methods_by_name['stat']._options = None
  _RESOURCEGROUP.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002$\"\"/inventory/v1/resource-groups/stat'
  _RESOURCE._serialized_start=200
  _RESOURCE._serialized_end=294
  _CREATERESOURCEGROUPREQUEST._serialized_start=297
  _CREATERESOURCEGROUPREQUEST._serialized_end=515
  _UPDATERESOURCEGROUPREQUEST._serialized_start=518
  _UPDATERESOURCEGROUPREQUEST._serialized_end=788
  _RESOURCEGROUPREQUEST._serialized_start=790
  _RESOURCEGROUPREQUEST._serialized_end=858
  _GETRESOURCEGROUPREQUEST._serialized_start=860
  _GETRESOURCEGROUPREQUEST._serialized_end=945
  _RESOURCEGROUPQUERY._serialized_start=948
  _RESOURCEGROUPQUERY._serialized_end=1092
  _RESOURCEGROUPINFO._serialized_start=1095
  _RESOURCEGROUPINFO._serialized_end=1351
  _RESOURCEGROUPSINFO._serialized_start=1353
  _RESOURCEGROUPSINFO._serialized_end=1457
  _RESOURCEGROUPSTATQUERY._serialized_start=1459
  _RESOURCEGROUPSTATQUERY._serialized_end=1556
  _RESOURCEGROUP._serialized_start=1559
  _RESOURCEGROUP._serialized_end=2511
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%spaceone/api/identity/v1/policy.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"r\n\x13\x43reatePolicyRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bpermissions\x18\x02 \x03(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\x85\x01\n\x13UpdatePolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x03(\t\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"5\n\rPolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"F\n\x10GetPolicyRequest\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"m\n\x0bPolicyQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tpolicy_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\x90\x01\n\nPolicyInfo\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x03(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x06 \x01(\t\"Z\n\x0cPoliciesInfo\x12\x35\n\x07results\x18\x01 \x03(\x0b\x32$.spaceone.api.identity.v1.PolicyInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"Z\n\x0fPolicyStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\x8d\x06\n\x06Policy\x12|\n\x06\x63reate\x12-.spaceone.api.identity.v1.CreatePolicyRequest\x1a$.spaceone.api.identity.v1.PolicyInfo\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x15/identity/v1/policies\x12\x86\x01\n\x06update\x12-.spaceone.api.identity.v1.UpdatePolicyRequest\x1a$.spaceone.api.identity.v1.PolicyInfo\"\'\x82\xd3\xe4\x93\x02!\x1a\x1f/identity/v1/policy/{policy_id}\x12r\n\x06\x64\x65lete\x12\'.spaceone.api.identity.v1.PolicyRequest\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!*\x1f/identity/v1/policy/{policy_id}\x12\x80\x01\n\x03get\x12*.spaceone.api.identity.v1.GetPolicyRequest\x1a$.spaceone.api.identity.v1.PolicyInfo\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/identity/v1/policy/{policy_id}\x12\x94\x01\n\x04list\x12%.spaceone.api.identity.v1.PolicyQuery\x1a&.spaceone.api.identity.v1.PoliciesInfo\"=\x82\xd3\xe4\x93\x02\x37\x12\x15/identity/v1/policiesZ\x1e\"\x1c/identity/v1/policies/search\x12n\n\x04stat\x12).spaceone.api.identity.v1.PolicyStatQuery\x1a\x17.google.protobuf.Struct\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/identity/v1/policies/statb\x06proto3')



_CREATEPOLICYREQUEST = DESCRIPTOR.message_types_by_name['CreatePolicyRequest']
_UPDATEPOLICYREQUEST = DESCRIPTOR.message_types_by_name['UpdatePolicyRequest']
_POLICYREQUEST = DESCRIPTOR.message_types_by_name['PolicyRequest']
_GETPOLICYREQUEST = DESCRIPTOR.message_types_by_name['GetPolicyRequest']
_POLICYQUERY = DESCRIPTOR.message_types_by_name['PolicyQuery']
_POLICYINFO = DESCRIPTOR.message_types_by_name['PolicyInfo']
_POLICIESINFO = DESCRIPTOR.message_types_by_name['PoliciesInfo']
_POLICYSTATQUERY = DESCRIPTOR.message_types_by_name['PolicyStatQuery']
CreatePolicyRequest = _reflection.GeneratedProtocolMessageType('CreatePolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOLICYREQUEST,
  '__module__' : 'spaceone.api.identity.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreatePolicyRequest)
  })
_sym_db.RegisterMessage(CreatePolicyRequest)

UpdatePolicyRequest = _reflection.GeneratedProtocolMessageType('UpdatePolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPOLICYREQUEST,
  '__module__' : 'spaceone.api.identity.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdatePolicyRequest)
  })
_sym_db.RegisterMessage(UpdatePolicyRequest)

PolicyRequest = _reflection.GeneratedProtocolMessageType('PolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _POLICYREQUEST,
  '__module__' : 'spaceone.api.identity.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.PolicyRequest)
  })
_sym_db.RegisterMessage(PolicyRequest)

GetPolicyRequest = _reflection.GeneratedProtocolMessageType('GetPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOLICYREQUEST,
  '__module__' : 'spaceone.api.identity.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetPolicyRequest)
  })
_sym_db.RegisterMessage(GetPolicyRequest)

PolicyQuery = _reflection.GeneratedProtocolMessageType('PolicyQuery', (_message.Message,), {
  'DESCRIPTOR' : _POLICYQUERY,
  '__module__' : 'spaceone.api.identity.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.PolicyQuery)
  })
_sym_db.RegisterMessage(PolicyQuery)

PolicyInfo = _reflection.GeneratedProtocolMessageType('PolicyInfo', (_message.Message,), {
  'DESCRIPTOR' : _POLICYINFO,
  '__module__' : 'spaceone.api.identity.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.PolicyInfo)
  })
_sym_db.RegisterMessage(PolicyInfo)

PoliciesInfo = _reflection.GeneratedProtocolMessageType('PoliciesInfo', (_message.Message,), {
  'DESCRIPTOR' : _POLICIESINFO,
  '__module__' : 'spaceone.api.identity.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.PoliciesInfo)
  })
_sym_db.RegisterMessage(PoliciesInfo)

PolicyStatQuery = _reflection.GeneratedProtocolMessageType('PolicyStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _POLICYSTATQUERY,
  '__module__' : 'spaceone.api.identity.v1.policy_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.PolicyStatQuery)
  })
_sym_db.RegisterMessage(PolicyStatQuery)

_POLICY = DESCRIPTOR.services_by_name['Policy']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _POLICY.methods_by_name['create']._options = None
  _POLICY.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\027\"\025/identity/v1/policies'
  _POLICY.methods_by_name['update']._options = None
  _POLICY.methods_by_name['update']._serialized_options = b'\202\323\344\223\002!\032\037/identity/v1/policy/{policy_id}'
  _POLICY.methods_by_name['delete']._options = None
  _POLICY.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002!*\037/identity/v1/policy/{policy_id}'
  _POLICY.methods_by_name['get']._options = None
  _POLICY.methods_by_name['get']._serialized_options = b'\202\323\344\223\002!\022\037/identity/v1/policy/{policy_id}'
  _POLICY.methods_by_name['list']._options = None
  _POLICY.methods_by_name['list']._serialized_options = b'\202\323\344\223\0027\022\025/identity/v1/policiesZ\036\"\034/identity/v1/policies/search'
  _POLICY.methods_by_name['stat']._options = None
  _POLICY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\034\"\032/identity/v1/policies/stat'
  _CREATEPOLICYREQUEST._serialized_start=190
  _CREATEPOLICYREQUEST._serialized_end=304
  _UPDATEPOLICYREQUEST._serialized_start=307
  _UPDATEPOLICYREQUEST._serialized_end=440
  _POLICYREQUEST._serialized_start=442
  _POLICYREQUEST._serialized_end=495
  _GETPOLICYREQUEST._serialized_start=497
  _GETPOLICYREQUEST._serialized_end=567
  _POLICYQUERY._serialized_start=569
  _POLICYQUERY._serialized_end=678
  _POLICYINFO._serialized_start=681
  _POLICYINFO._serialized_end=825
  _POLICIESINFO._serialized_start=827
  _POLICIESINFO._serialized_end=917
  _POLICYSTATQUERY._serialized_start=919
  _POLICYSTATQUERY._serialized_end=1009
  _POLICY._serialized_start=1012
  _POLICY._serialized_end=1793
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/core/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n spaceone/api/core/v1/query.proto\x12\x14spaceone.api.core.v1\x1a\x1cgoogle/protobuf/struct.proto\"\xc1\x01\n\x06\x46ilter\x12\r\n\x03key\x18\x01 \x01(\tH\x00\x12\x0b\n\x01k\x18\x02 \x01(\tH\x00\x12\'\n\x05value\x18\x03 \x01(\x0b\x32\x16.google.protobuf.ValueH\x01\x12#\n\x01v\x18\x04 \x01(\x0b\x32\x16.google.protobuf.ValueH\x01\x12\x12\n\x08operator\x18\x05 \x01(\tH\x02\x12\x0b\n\x01o\x18\x06 \x01(\tH\x02\x42\x0b\n\tkey_aliasB\r\n\x0bvalue_aliasB\x10\n\x0eoperator_alias\"$\n\x07SortKey\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\x08\"N\n\x04Sort\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\x08\x12+\n\x04keys\x18\x03 \x03(\x0b\x32\x1d.spaceone.api.core.v1.SortKey\"$\n\x04Page\x12\r\n\x05start\x18\x01 \x01(\r\x12\r\n\x05limit\x18\x02 \x01(\r\"\xfe\x01\n\x05Query\x12,\n\x06\x66ilter\x18\x01 \x03(\x0b\x32\x1c.spaceone.api.core.v1.Filter\x12/\n\tfilter_or\x18\x02 \x03(\x0b\x32\x1c.spaceone.api.core.v1.Filter\x12(\n\x04sort\x18\x03 \x01(\x0b\x32\x1a.spaceone.api.core.v1.Sort\x12(\n\x04page\x18\x04 \x01(\x0b\x32\x1a.spaceone.api.core.v1.Page\x12\x0f\n\x07minimal\x18\x05 \x01(\x08\x12\x12\n\ncount_only\x18\x06 \x01(\x08\x12\x0c\n\x04only\x18\x07 \x03(\t\x12\x0f\n\x07keyword\x18\x08 \x01(\t\"|\n\x11\x41ggregateGroupKey\x12\r\n\x03key\x18\x01 \x01(\tH\x00\x12\x0b\n\x01k\x18\x02 \x01(\tH\x00\x12\x0e\n\x04name\x18\x03 \x01(\tH\x01\x12\x0b\n\x01n\x18\x04 \x01(\tH\x01\x12\x13\n\x0b\x64\x61te_format\x18\x05 \x01(\tB\x0b\n\tkey_aliasB\x0c\n\nname_alias\"l\n\x16\x41ggregateGroupSubField\x12\r\n\x03key\x18\x01 \x01(\tH\x00\x12\x0b\n\x01k\x18\x02 \x01(\tH\x00\x12\x0e\n\x04name\x18\x03 \x01(\tH\x01\x12\x0b\n\x01n\x18\x04 \x01(\tH\x01\x42\x0b\n\tkey_aliasB\x0c\n\nname_alias\"\xd0\x01\n\x15\x41ggregateSubCondition\x12\r\n\x03key\x18\x01 \x01(\tH\x00\x12\x0b\n\x01k\x18\x02 \x01(\tH\x00\x12\'\n\x05value\x18\x03 \x01(\x0b\x32\x16.google.protobuf.ValueH\x01\x12#\n\x01v\x18\x04 \x01(\x0b\x32\x16.google.protobuf.ValueH\x01\x12\x12\n\x08operator\x18\x05 \x01(\tH\x02\x12\x0b\n\x01o\x18\x06 \x01(\tH\x02\x42\x0b\n\tkey_aliasB\r\n\x0bvalue_aliasB\x10\n\x0eoperator_alias\"\x9b\x02\n\x13\x41ggregateGroupField\x12\r\n\x03key\x18\x01 \x01(\tH\x00\x12\x0b\n\x01k\x18\x02 \x01(\tH\x00\x12\x0e\n\x04name\x18\x03 \x01(\tH\x01\x12\x0b\n\x01n\x18\x04 \x01(\tH\x01\x12\x12\n\x08operator\x18\x05 \x01(\tH\x02\x12\x0b\n\x01o\x18\x06 \x01(\tH\x02\x12<\n\x06\x66ields\x18\x07 \x03(\x0b\x32,.spaceone.api.core.v1.AggregateGroupSubField\x12?\n\nconditions\x18\x08 \x03(\x0b\x32+.spaceone.api.core.v1.AggregateSubConditionB\x0b\n\tkey_aliasB\x0c\n\nname_aliasB\x10\n\x0eoperator_alias\"\x82\x01\n\x0e\x41ggregateGroup\x12\x35\n\x04keys\x18\x01 \x03(\x0b\x32\'.spaceone.api.core.v1.AggregateGroupKey\x12\x39\n\x06\x66ields\x18\x02 \x03(\x0b\x32).spaceone.api.core.v1.AggregateGroupField\"\x9e\x01\n\x15\x41ggregateProjectField\x12\r\n\x03key\x18\x01 \x01(\tH\x00\x12\x0b\n\x01k\x18\x02 \x01(\tH\x00\x12\x0e\n\x04name\x18\x03 \x01(\tH\x01\x12\x0b\n\x01n\x18\x04 \x01(\tH\x01\x12\x12\n\x08operator\x18\x05 \x01(\tH\x02\x12\x0b\n\x01o\x18\x06 \x01(\tH\x02\x42\x0b\n\tkey_aliasB\x0c\n\nname_aliasB\x10\n\x0eoperator_alias\"e\n\x10\x41ggregateProject\x12;\n\x06\x66ields\x18\x01 \x03(\x0b\x32+.spaceone.api.core.v1.AggregateProjectField\x12\x14\n\x0c\x65xclude_keys\x18\x02 \x01(\x08\"\x1f\n\x0f\x41ggregateUnwind\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x1e\n\x0e\x41ggregateCount\x12\x0c\n\x04name\x18\x01 \x01(\t\"W\n\rAggregateSort\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\x08\x12+\n\x04keys\x18\x03 \x03(\x0b\x32\x1d.spaceone.api.core.v1.SortKey\"\xe0\x02\n\x13StatisticsAggregate\x12\x37\n\x06unwind\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.AggregateUnwindH\x00\x12\x35\n\x05group\x18\x02 \x01(\x0b\x32$.spaceone.api.core.v1.AggregateGroupH\x00\x12\x35\n\x05\x63ount\x18\x03 \x01(\x0b\x32$.spaceone.api.core.v1.AggregateCountH\x00\x12\x33\n\x04sort\x18\x04 \x01(\x0b\x32#.spaceone.api.core.v1.AggregateSortH\x00\x12\x39\n\x07project\x18\x05 \x01(\x0b\x32&.spaceone.api.core.v1.AggregateProjectH\x00\x12\x0f\n\x05limit\x18\x06 \x01(\x05H\x00\x12\x0e\n\x04skip\x18\x07 \x01(\x05H\x00\x42\x11\n\x0f\x61ggregate_alias\"\xfb\x01\n\x0fStatisticsQuery\x12,\n\x06\x66ilter\x18\x01 \x03(\x0b\x32\x1c.spaceone.api.core.v1.Filter\x12/\n\tfilter_or\x18\x02 \x03(\x0b\x32\x1c.spaceone.api.core.v1.Filter\x12<\n\taggregate\x18\x03 \x03(\x0b\x32).spaceone.api.core.v1.StatisticsAggregate\x12(\n\x04page\x18\x04 \x01(\x0b\x32\x1a.spaceone.api.core.v1.Page\x12\x10\n\x08\x64istinct\x18\x05 \x01(\t\x12\x0f\n\x07keyword\x18\x06 \x01(\tb\x06proto3')



_FILTER = DESCRIPTOR.message_types_by_name['Filter']
_SORTKEY = DESCRIPTOR.message_types_by_name['SortKey']
_SORT = DESCRIPTOR.message_types_by_name['Sort']
_PAGE = DESCRIPTOR.message_types_by_name['Page']
_QUERY = DESCRIPTOR.message_types_by_name['Query']
_AGGREGATEGROUPKEY = DESCRIPTOR.message_types_by_name['AggregateGroupKey']
_AGGREGATEGROUPSUBFIELD = DESCRIPTOR.message_types_by_name['AggregateGroupSubField']
_AGGREGATESUBCONDITION = DESCRIPTOR.message_types_by_name['AggregateSubCondition']
_AGGREGATEGROUPFIELD = DESCRIPTOR.message_types_by_name['AggregateGroupField']
_AGGREGATEGROUP = DESCRIPTOR.message_types_by_name['AggregateGroup']
_AGGREGATEPROJECTFIELD = DESCRIPTOR.message_types_by_name['AggregateProjectField']
_AGGREGATEPROJECT = DESCRIPTOR.message_types_by_name['AggregateProject']
_AGGREGATEUNWIND = DESCRIPTOR.message_types_by_name['AggregateUnwind']
_AGGREGATECOUNT = DESCRIPTOR.message_types_by_name['AggregateCount']
_AGGREGATESORT = DESCRIPTOR.message_types_by_name['AggregateSort']
_STATISTICSAGGREGATE = DESCRIPTOR.message_types_by_name['StatisticsAggregate']
_STATISTICSQUERY = DESCRIPTOR.message_types_by_name['StatisticsQuery']
Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.Filter)
  })
_sym_db.RegisterMessage(Filter)

SortKey = _reflection.GeneratedProtocolMessageType('SortKey', (_message.Message,), {
  'DESCRIPTOR' : _SORTKEY,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.SortKey)
  })
_sym_db.RegisterMessage(SortKey)

Sort = _reflection.GeneratedProtocolMessageType('Sort', (_message.Message,), {
  'DESCRIPTOR' : _SORT,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.Sort)
  })
_sym_db.RegisterMessage(Sort)

Page = _reflection.GeneratedProtocolMessageType('Page', (_message.Message,), {
  'DESCRIPTOR' : _PAGE,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.Page)
  })
_sym_db.RegisterMessage(Page)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), {
  'DESCRIPTOR' : _QUERY,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.Query)
  })
_sym_db.RegisterMessage(Query)

AggregateGroupKey = _reflection.GeneratedProtocolMessageType('AggregateGroupKey', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEGROUPKEY,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AggregateGroupKey)
  })
_sym_db.RegisterMessage(AggregateGroupKey)

AggregateGroupSubField = _reflection.GeneratedProtocolMessageType('AggregateGroupSubField', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEGROUPSUBFIELD,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AggregateGroupSubField)
  })
_sym_db.RegisterMessage(AggregateGroupSubField)

AggregateSubCondition = _reflection.GeneratedProtocolMessageType('AggregateSubCondition', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATESUBCONDITION,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AggregateSubCondition)
  })
_sym_db.RegisterMessage(AggregateSubCondition)

AggregateGroupField = _reflection.GeneratedProtocolMessageType('AggregateGroupField', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEGROUPFIELD,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AggregateGroupField)
  })
_sym_db.RegisterMessage(AggregateGroupField)

AggregateGroup = _reflection.GeneratedProtocolMessageType('AggregateGroup', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEGROUP,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AggregateGroup)
  })
_sym_db.RegisterMessage(AggregateGroup)

AggregateProjectField = _reflection.GeneratedProtocolMessageType('AggregateProjectField', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEPROJECTFIELD,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AggregateProjectField)
  })
_sym_db.RegisterMessage(AggregateProjectField)

AggregateProject = _reflection.GeneratedProtocolMessageType('AggregateProject', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEPROJECT,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AggregateProject)
  })
_sym_db.RegisterMessage(AggregateProject)

AggregateUnwind = _reflection.GeneratedProtocolMessageType('AggregateUnwind', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEUNWIND,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AggregateUnwind)
  })
_sym_db.RegisterMessage(AggregateUnwind)

AggregateCount = _reflection.GeneratedProtocolMessageType('AggregateCount', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATECOUNT,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AggregateCount)
  })
_sym_db.RegisterMessage(AggregateCount)

AggregateSort = _reflection.GeneratedProtocolMessageType('AggregateSort', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATESORT,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.AggregateSort)
  })
_sym_db.RegisterMessage(AggregateSort)

StatisticsAggregate = _reflection.GeneratedProtocolMessageType('StatisticsAggregate', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICSAGGREGATE,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.StatisticsAggregate)
  })
_sym_db.RegisterMessage(StatisticsAggregate)

StatisticsQuery = _reflection.GeneratedProtocolMessageType('StatisticsQuery', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICSQUERY,
  '__module__' : 'spaceone.api.core.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.StatisticsQuery)
  })
_sym_db.RegisterMessage(StatisticsQuery)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FILTER._serialized_start=89
  _FILTER._serialized_end=282
  _SORTKEY._serialized_start=284
  _SORTKEY._serialized_end=320
  _SORT._serialized_start=322
  _SORT._serialized_end=400
  _PAGE._serialized_start=402
  _PAGE._serialized_end=438
  _QUERY._serialized_start=441
  _QUERY._serialized_end=695
  _AGGREGATEGROUPKEY._serialized_start=697
  _AGGREGATEGROUPKEY._serialized_end=821
  _AGGREGATEGROUPSUBFIELD._serialized_start=823
  _AGGREGATEGROUPSUBFIELD._serialized_end=931
  _AGGREGATESUBCONDITION._serialized_start=934
  _AGGREGATESUBCONDITION._serialized_end=1142
  _AGGREGATEGROUPFIELD._serialized_start=1145
  _AGGREGATEGROUPFIELD._serialized_end=1428
  _AGGREGATEGROUP._serialized_start=1431
  _AGGREGATEGROUP._serialized_end=1561
  _AGGREGATEPROJECTFIELD._serialized_start=1564
  _AGGREGATEPROJECTFIELD._serialized_end=1722
  _AGGREGATEPROJECT._serialized_start=1724
  _AGGREGATEPROJECT._serialized_end=1825
  _AGGREGATEUNWIND._serialized_start=1827
  _AGGREGATEUNWIND._serialized_end=1858
  _AGGREGATECOUNT._serialized_start=1860
  _AGGREGATECOUNT._serialized_end=1890
  _AGGREGATESORT._serialized_start=1892
  _AGGREGATESORT._serialized_end=1979
  _STATISTICSAGGREGATE._serialized_start=1982
  _STATISTICSAGGREGATE._serialized_end=2334
  _STATISTICSQUERY._serialized_start=2337
  _STATISTICSQUERY._serialized_end=2588
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/change_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.spaceone/api/inventory/v1/change_history.proto\x12\x19spaceone.api.inventory.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xc2\x02\n\x12\x43hangeHistoryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x18\n\x10\x63loud_service_id\x18\x02 \x01(\t\x12J\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32:.spaceone.api.inventory.v1.ChangeHistoryQuery.RecordAction\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x14\n\x0c\x63ollector_id\x18\x05 \x01(\t\x12\x0e\n\x06job_id\x18\x06 \x01(\t\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12\x11\n\tdomain_id\x18\x08 \x01(\t\"<\n\x0cRecordAction\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\"\xeb\x02\n\nRecordInfo\x12\x11\n\trecord_id\x18\x01 \x01(\t\x12\x18\n\x10\x63loud_service_id\x18\x02 \x01(\t\x12\x42\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x32.spaceone.api.inventory.v1.RecordInfo.RecordAction\x12(\n\x04\x64iff\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x12\n\ndiff_count\x18\x05 \x01(\x05\x12\x0f\n\x07user_id\x18\x06 \x01(\t\x12\x14\n\x0c\x63ollector_id\x18\x07 \x01(\t\x12\x0e\n\x06job_id\x18\x08 \x01(\t\x12\x12\n\nupdated_by\x18\t \x01(\t\x12\x11\n\tdomain_id\x18\n \x01(\t\x12\x12\n\ncreated_at\x18\x0b \x01(\t\"<\n\x0cRecordAction\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\"`\n\x11\x43hangeHistoryInfo\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.spaceone.api.inventory.v1.RecordInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"{\n\x16\x43hangeHistoryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x18\n\x10\x63loud_service_id\x18\x03 \x01(\t2\x94\x03\n\rChangeHistory\x12\xf4\x01\n\x04list\x12-.spaceone.api.inventory.v1.ChangeHistoryQuery\x1a,.spaceone.api.inventory.v1.ChangeHistoryInfo\"\x8e\x01\x82\xd3\xe4\x93\x02\x87\x01\x12=/inventory/v1/cloud-service/{cloud_service_id}/change-historyZF\"D/inventory/v1/cloud-service/{cloud_service_id}/change-history/search\x12\x8b\x01\n\x04stat\x12\x31.spaceone.api.inventory.v1.ChangeHistoryStatQuery\x1a\x17.google.protobuf.Struct\"7\x82\xd3\xe4\x93\x02\x31\"//inventory/v1/cloud-service/change-history/statb\x06proto3')



_CHANGEHISTORYQUERY = DESCRIPTOR.message_types_by_name['ChangeHistoryQuery']
_RECORDINFO = DESCRIPTOR.message_types_by_name['RecordInfo']
_CHANGEHISTORYINFO = DESCRIPTOR.message_types_by_name['ChangeHistoryInfo']
_CHANGEHISTORYSTATQUERY = DESCRIPTOR.message_types_by_name['ChangeHistoryStatQuery']
_CHANGEHISTORYQUERY_RECORDACTION = _CHANGEHISTORYQUERY.enum_types_by_name['RecordAction']
_RECORDINFO_RECORDACTION = _RECORDINFO.enum_types_by_name['RecordAction']
ChangeHistoryQuery = _reflection.GeneratedProtocolMessageType('ChangeHistoryQuery', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEHISTORYQUERY,
  '__module__' : 'spaceone.api.inventory.v1.change_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ChangeHistoryQuery)
  })
_sym_db.RegisterMessage(ChangeHistoryQuery)

RecordInfo = _reflection.GeneratedProtocolMessageType('RecordInfo', (_message.Message,), {
  'DESCRIPTOR' : _RECORDINFO,
  '__module__' : 'spaceone.api.inventory.v1.change_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.RecordInfo)
  })
_sym_db.RegisterMessage(RecordInfo)

ChangeHistoryInfo = _reflection.GeneratedProtocolMessageType('ChangeHistoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEHISTORYINFO,
  '__module__' : 'spaceone.api.inventory.v1.change_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ChangeHistoryInfo)
  })
_sym_db.RegisterMessage(ChangeHistoryInfo)

ChangeHistoryStatQuery = _reflection.GeneratedProtocolMessageType('ChangeHistoryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEHISTORYSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.change_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ChangeHistoryStatQuery)
  })
_sym_db.RegisterMessage(ChangeHistoryStatQuery)

_CHANGEHISTORY = DESCRIPTOR.services_by_name['ChangeHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHANGEHISTORY.methods_by_name['list']._options = None
  _CHANGEHISTORY.methods_by_name['list']._serialized_options = b'\202\323\344\223\002\207\001\022=/inventory/v1/cloud-service/{cloud_service_id}/change-historyZF\"D/inventory/v1/cloud-service/{cloud_service_id}/change-history/search'
  _CHANGEHISTORY.methods_by_name['stat']._options = None
  _CHANGEHISTORY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\0021\"//inventory/v1/cloud-service/change-history/stat'
  _CHANGEHISTORYQUERY._serialized_start=172
  _CHANGEHISTORYQUERY._serialized_end=494
  _CHANGEHISTORYQUERY_RECORDACTION._serialized_start=434
  _CHANGEHISTORYQUERY_RECORDACTION._serialized_end=494
  _RECORDINFO._serialized_start=497
  _RECORDINFO._serialized_end=860
  _RECORDINFO_RECORDACTION._serialized_start=434
  _RECORDINFO_RECORDACTION._serialized_end=494
  _CHANGEHISTORYINFO._serialized_start=862
  _CHANGEHISTORYINFO._serialized_end=958
  _CHANGEHISTORYSTATQUERY._serialized_start=960
  _CHANGEHISTORYSTATQUERY._serialized_end=1083
  _CHANGEHISTORY._serialized_start=1086
  _CHANGEHISTORY._serialized_end=1490
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.statistics.v1 import schedule_pb2 as spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2


class ScheduleStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.add = channel.unary_unary(
                '/spaceone.api.statistics.v1.Schedule/add',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.AddScheduleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.statistics.v1.Schedule/update',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.UpdateScheduleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.statistics.v1.Schedule/enable',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.statistics.v1.Schedule/disable',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.statistics.v1.Schedule/delete',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.statistics.v1.Schedule/get',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.GetScheduleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.statistics.v1.Schedule/list',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.SchedulesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.statistics.v1.Schedule/stat',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class ScheduleServicer(object):
    """Missing associated documentation comment in .proto file."""

    def add(self, request, context):
        """
        desc: Adds a new Schedule. When creating, `topic` and queries to be used should be specified. The time interval of the Schedule should be also specified to run queries repeatedly. The run set by Schedule starts every hour on the hour.
        request_example: >-
        {
        "topic": "daily_cloud_service_summary_test",
        "options": {"aggregate": [{"query": {
        "extend_data": {"label": "Server"}, "query": {
        "filter": [{"key": "ref_cloud_service_type.is_primary", "value": true, "operator": "eq"},
        {"value": "Server", "operator": "eq", "key": "ref_cloud_service_type.labels"}],
        "aggregate": [{"group": {
        "fields": [
        {
        "name": "value",
        "operator": "count"}],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"},
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"},
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"},
        {
        "key": "provider",
        "name": "provider"}]}}]},
        "resource_type": "inventory.CloudService"}}, {"concat": {"resource_type": "inventory.CloudService", "query": {
        "aggregate": [{"group": {"keys": [{"key": "project_id", "name": "project_id"},
        {"name": "cloud_service_type", "key": "cloud_service_type"},
        {"key": "cloud_service_group", "name": "cloud_service_group"},
        {"key": "provider", "name": "provider"}],
        "fields": [{"name": "value", "operator": "count"}]}}],
        "filter": [{"value": true, "operator": "eq", "key": "ref_cloud_service_type.is_primary"},
        {"value": "Database", "operator": "eq", "key": "ref_cloud_service_type.labels"}]},
        "extend_data": {"label": "Database"}}}, {"concat": {
        "resource_type": "inventory.CloudService", "extend_data": {"label": "Container"}, "query": {
        "filter": [{"value": true, "key": "ref_cloud_service_type.is_primary", "operator": "eq"},
        {"key": "ref_cloud_service_type.labels", "value": "Container", "operator": "eq"}],
        "aggregate": [{
        "group": {
        "fields": [
        {
        "name": "value",
        "operator": "count"}],
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"},
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"},
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"},
        {
        "key": "provider",
        "name": "provider"}]}}]}}},
        {"concat": {
        "extend_data": {"label": "Networking"},
        "query": {"aggregate": [{"group": {
        "keys": [{"name": "project_id",
        "key": "project_id"}, {
        "key": "cloud_service_type",
        "name": "cloud_service_type"},
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"},
        {"key": "provider",
        "name": "provider"}],
        "fields": [{"name": "value",
        "operator": "count"}]}}],
        "filter": [{
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq",
        "value": true},
        {
        "key": "ref_cloud_service_type.labels",
        "value": "Networking",
        "operator": "eq"}]},
        "resource_type": "inventory.CloudService"}},
        {"concat": {
        "resource_type": "inventory.CloudService",
        "query": {"filter": [{
        "key": "ref_cloud_service_type.is_primary",
        "value": true,
        "operator": "eq"},
        {"operator": "eq",
        "value": "Security",
        "key": "ref_cloud_service_type.labels"}],
        "aggregate": [{"group": {
        "keys": [
        {"key": "project_id",
        "name": "project_id"},
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"},
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"},
        {"key": "provider",
        "name": "provider"}],
        "fields": [
        {"name": "value",
        "operator": "count"}]}}]},
        "extend_data": {"label": "Security"}}},
        {"concat": {
        "resource_type": "inventory.CloudService",
        "extend_data": {"label": "Analytics"},
        "query": {"filter": [{"value": true,
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq"},
        {"operator": "eq",
        "value": "Analytics",
        "key": "ref_cloud_service_type.labels"}],
        "aggregate": [{"group": {
        "fields": [
        {"operator": "count",
        "name": "value"}],
        "keys": [
        {"name": "project_id",
        "key": "project_id"},
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"},
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"},
        {"key": "provider",
        "name": "provider"}]}}]}}},
        {"concat": {
        "resource_type": "inventory.CloudService",
        "extend_data": {"label": "All"},
        "query": {"aggregate": [{"group": {
        "keys": [{"name": "project_id",
        "key": "project_id"}, {
        "name": "cloud_service_type",
        "key": "cloud_service_type"},
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"},
        {"key": "provider",
        "name": "provider"}],
        "fields": [{"operator": "count",
        "name": "value"}]}}],
        "filter": [{
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq",
        "value": true}]}}},
        {"concat": {"query": {"filter": [
        {"value": true, "operator": "eq",
        "key": "ref_cloud_service_type.is_major"},
        {"value": "Storage", "operator": "eq",
        "key": "ref_cloud_service_type.labels"}],
        "aggregate": [{
        "group": {
        "fields": [
        {
        "name": "value",
        "key": "data.size",
        "operator": "sum"}],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"},
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"},
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"},
        {
        "key": "provider",
        "name": "provider"}]}}]},
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Storage"}
        }}]},
        "schedule": {"hours": [1]},
        "tags": {},
        "domain_id": "domain-58010aa2e451"}

        response_example: >-
        {
        "schedule_id": "sch-65bb6b55d162",
        "topic": "daily_cloud_service_summary_test",
        "state": "ENABLED",
        "options": {
        "aggregate": [
        {
        "query": {
        "extend_data": {
        "label": "Server"
        },
        "resource_type": "inventory.CloudService",
        "query": {
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "value": true,
        "operator": "eq"
        },
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.labels",
        "value": "Server"
        }
        ],
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ]
        }
        }
        },
        {
        "concat": {
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "operator": "eq",
        "value": true,
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.labels",
        "value": "Database"
        }
        ]
        },
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Database"
        }
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ],
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "value": true,
        "operator": "eq"
        },
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.labels",
        "value": "Container"
        }
        ]
        },
        "extend_data": {
        "label": "Container"
        }
        }
        },
        {
        "concat": {
        "query": {
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq",
        "value": true
        },
        {
        "key": "ref_cloud_service_type.labels",
        "operator": "eq",
        "value": "Networking"
        }
        ]
        },
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Networking"
        }
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Security"
        },
        "query": {
        "filter": [
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary",
        "value": true
        },
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.labels",
        "value": "Security"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ]
        }
        }
        ]
        }
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "query": {
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "value": true,
        "operator": "eq"
        },
        {
        "key": "ref_cloud_service_type.labels",
        "value": "Analytics",
        "operator": "eq"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ]
        }
        }
        ]
        },
        "extend_data": {
        "label": "Analytics"
        }
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "All"
        },
        "resource_type": "inventory.CloudService",
        "query": {
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "value": true,
        "operator": "eq"
        }
        ],
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ],
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ]
        }
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "operator": "sum",
        "name": "value",
        "key": "data.size"
        }
        ],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.is_major",
        "value": true
        },
        {
        "value": "Storage",
        "operator": "eq",
        "key": "ref_cloud_service_type.labels"
        }
        ]
        },
        "extend_data": {
        "label": "Storage"
        }
        }
        }
        ]
        },
        "schedule": {
        "hours": [
        1
        ]
        },
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-26T02:08:48.233Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Schedule. You can make changes in Schedule settings, including time intervals.
        request_example: >-
        {
        "schedule_id": "sch-65bb6b55d162",
        "schedule": {"hours": [2]},
        "tags": {"a": "b"},
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "schedule_id": "sch-65bb6b55d162",
        "topic": "daily_cloud_service_summary_test",
        "state": "ENABLED",
        "options": {
        "aggregate": [
        {
        "query": {
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Server"
        },
        "query": {
        "filter": [
        {
        "value": true,
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "key": "ref_cloud_service_type.labels",
        "value": "Server",
        "operator": "eq"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ]
        }
        }
        ]
        }
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "Database"
        },
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ],
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "operator": "eq",
        "value": true,
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "value": "Database",
        "key": "ref_cloud_service_type.labels",
        "operator": "eq"
        }
        ]
        },
        "resource_type": "inventory.CloudService"
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "Container"
        },
        "query": {
        "filter": [
        {
        "value": true,
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq"
        },
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.labels",
        "value": "Container"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ],
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ]
        }
        }
        ]
        },
        "resource_type": "inventory.CloudService"
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ],
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "operator": "eq",
        "value": true,
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "operator": "eq",
        "value": "Networking",
        "key": "ref_cloud_service_type.labels"
        }
        ]
        },
        "extend_data": {
        "label": "Networking"
        }
        }
        },
        {
        "concat": {
        "query": {
        "filter": [
        {
        "value": true,
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq"
        },
        {
        "key": "ref_cloud_service_type.labels",
        "operator": "eq",
        "value": "Security"
        }
        ],
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ]
        }
        }
        ]
        },
        "extend_data": {
        "label": "Security"
        },
        "resource_type": "inventory.CloudService"
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Analytics"
        },
        "query": {
        "filter": [
        {
        "value": true,
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "key": "ref_cloud_service_type.labels",
        "operator": "eq",
        "value": "Analytics"
        }
        ],
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ]
        }
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "All"
        },
        "query": {
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "value": true,
        "operator": "eq"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ],
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ]
        }
        }
        ]
        }
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "Storage"
        },
        "resource_type": "inventory.CloudService",
        "query": {
        "filter": [
        {
        "key": "ref_cloud_service_type.is_major",
        "operator": "eq",
        "value": true
        },
        {
        "value": "Storage",
        "key": "ref_cloud_service_type.labels",
        "operator": "eq"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "key": "data.size",
        "name": "value",
        "operator": "sum"
        }
        ]
        }
        }
        ]
        }
        }
        }
        ]
        },
        "schedule": {
        "hours": [
        2
        ]
        },
        "tags": {
        "a": "b"
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-26T02:08:48.233Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """
        desc: Enables a specific Schedule. If a Schedule is enabled, the query usage will be scheduled by the time interval specified.
        request_example: >-
        {
        "schedule_id": "sch-65bb6b55d162",
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "schedule_id": "sch-65bb6b55d162",
        "topic": "daily_cloud_service_summary_test",
        "state": "ENABLED",
        "options": {
        "aggregate": [
        {
        "query": {
        "query": {
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "value": true,
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "value": "Server",
        "operator": "eq",
        "key": "ref_cloud_service_type.labels"
        }
        ]
        },
        "extend_data": {
        "label": "Server"
        },
        "resource_type": "inventory.CloudService"
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Database"
        },
        "query": {
        "filter": [
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary",
        "value": true
        },
        {
        "value": "Database",
        "operator": "eq",
        "key": "ref_cloud_service_type.labels"
        }
        ],
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ]
        }
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Container"
        },
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ],
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq",
        "value": true
        },
        {
        "key": "ref_cloud_service_type.labels",
        "value": "Container",
        "operator": "eq"
        }
        ]
        }
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "Networking"
        },
        "resource_type": "inventory.CloudService",
        "query": {
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ],
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "value": true,
        "operator": "eq"
        },
        {
        "key": "ref_cloud_service_type.labels",
        "operator": "eq",
        "value": "Networking"
        }
        ]
        }
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Security"
        },
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "value": true,
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "value": "Security",
        "operator": "eq",
        "key": "ref_cloud_service_type.labels"
        }
        ]
        }
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "Analytics"
        },
        "resource_type": "inventory.CloudService",
        "query": {
        "filter": [
        {
        "operator": "eq",
        "value": true,
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "operator": "eq",
        "value": "Analytics",
        "key": "ref_cloud_service_type.labels"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ]
        }
        }
        ]
        }
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "All"
        },
        "query": {
        "filter": [
        {
        "value": true,
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ]
        }
        }
        ]
        },
        "resource_type": "inventory.CloudService"
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "Storage"
        },
        "resource_type": "inventory.CloudService",
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "key": "data.size",
        "name": "value",
        "operator": "sum"
        }
        ],
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "value": true,
        "key": "ref_cloud_service_type.is_major",
        "operator": "eq"
        },
        {
        "value": "Storage",
        "key": "ref_cloud_service_type.labels",
        "operator": "eq"
        }
        ]
        }
        }
        }
        ]
        },
        "schedule": {
        "hours": [
        2
        ]
        },
        "tags": {
        "a": "b"
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-26T02:08:48.233Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """
        desc: Disables a specific Schedule. If a Schedule is disabled, the query usage will not be scheduled.
        request_example: >-
        {
        "schedule_id": "sch-65bb6b55d162",
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "schedule_id": "sch-65bb6b55d162",
        "topic": "daily_cloud_service_summary_test",
        "state": "DISABLED",
        "options": {
        "aggregate": [
        {
        "query": {
        "query": {
        "filter": [
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary",
        "value": true
        },
        {
        "operator": "eq",
        "value": "Server",
        "key": "ref_cloud_service_type.labels"
        }
        ],
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ]
        }
        }
        ]
        },
        "extend_data": {
        "label": "Server"
        },
        "resource_type": "inventory.CloudService"
        }
        },
        {
        "concat": {
        "query": {
        "filter": [
        {
        "operator": "eq",
        "value": true,
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.labels",
        "value": "Database"
        }
        ],
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ],
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ]
        }
        }
        ]
        },
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Database"
        }
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Container"
        },
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "operator": "eq",
        "value": true,
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "key": "ref_cloud_service_type.labels",
        "operator": "eq",
        "value": "Container"
        }
        ]
        }
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "Networking"
        },
        "query": {
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq",
        "value": true
        },
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.labels",
        "value": "Networking"
        }
        ],
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ],
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ]
        }
        }
        ]
        },
        "resource_type": "inventory.CloudService"
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Security"
        },
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ],
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "value": true,
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq"
        },
        {
        "operator": "eq",
        "value": "Security",
        "key": "ref_cloud_service_type.labels"
        }
        ]
        }
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Analytics"
        },
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "value": true,
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "key": "ref_cloud_service_type.labels",
        "value": "Analytics",
        "operator": "eq"
        }
        ]
        }
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "All"
        },
        "query": {
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary",
        "value": true
        }
        ]
        },
        "resource_type": "inventory.CloudService"
        }
        },
        {
        "concat": {
        "query": {
        "filter": [
        {
        "value": true,
        "key": "ref_cloud_service_type.is_major",
        "operator": "eq"
        },
        {
        "key": "ref_cloud_service_type.labels",
        "operator": "eq",
        "value": "Storage"
        }
        ],
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "key": "data.size",
        "operator": "sum",
        "name": "value"
        }
        ],
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ]
        },
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Storage"
        }
        }
        }
        ]
        },
        "schedule": {
        "hours": [
        2
        ]
        },
        "tags": {
        "a": "b"
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-26T02:08:48.233Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Schedule. You must specify the `schedule_id` of the Schedule to delete.
        request_example: >-
        {
        "schedule_id": "sch-3da9c9ed2ee2",
        "domain_id": "domain-58010aa2e451"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Schedule. Prints detailed information about the Schedule, including the schedule interval and `state`.
        request_example: >-
        {
        "schedule_id": "sch-3da9c9ed2ee2",
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "schedule_id": "sch-3da9c9ed2ee2",
        "topic": "daily_cloud_service_summary",
        "state": "ENABLED",
        "options": {
        "aggregate": [
        {
        "query": {
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Server"
        },
        "query": {
        "filter": [
        {
        "value": true,
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "value": "Server",
        "key": "ref_cloud_service_type.labels",
        "operator": "eq"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ],
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ]
        }
        }
        ]
        }
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "Database"
        },
        "resource_type": "inventory.CloudService",
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ],
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "value": true,
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "value": "Database",
        "operator": "eq",
        "key": "ref_cloud_service_type.labels"
        }
        ]
        }
        }
        },
        {
        "concat": {
        "query": {
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq",
        "value": true
        },
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.labels",
        "value": "Container"
        }
        ],
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ]
        },
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Container"
        }
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "Networking"
        },
        "resource_type": "inventory.CloudService",
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ],
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq",
        "value": true
        },
        {
        "operator": "eq",
        "value": "Networking",
        "key": "ref_cloud_service_type.labels"
        }
        ]
        }
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "query": {
        "filter": [
        {
        "value": true,
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "operator": "eq",
        "value": "Security",
        "key": "ref_cloud_service_type.labels"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ],
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ]
        }
        }
        ]
        },
        "extend_data": {
        "label": "Security"
        }
        }
        },
        {
        "concat": {
        "query": {
        "filter": [
        {
        "operator": "eq",
        "value": true,
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "key": "ref_cloud_service_type.labels",
        "operator": "eq",
        "value": "Analytics"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ],
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ]
        }
        }
        ]
        },
        "extend_data": {
        "label": "Analytics"
        },
        "resource_type": "inventory.CloudService"
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "All"
        },
        "resource_type": "inventory.CloudService",
        "query": {
        "filter": [
        {
        "value": true,
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq"
        }
        ],
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ]
        }
        }
        ]
        }
        }
        },
        {
        "concat": {
        "query": {
        "filter": [
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.is_major",
        "value": true
        },
        {
        "value": "Storage",
        "key": "ref_cloud_service_type.labels",
        "operator": "eq"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ],
        "fields": [
        {
        "key": "data.size",
        "operator": "sum",
        "name": "value"
        }
        ]
        }
        }
        ]
        },
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Storage"
        }
        }
        }
        ]
        },
        "schedule": {
        "hours": [
        1
        ]
        },
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-13T11:41:35.811Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Schedules. You can use a query to get a filtered list of Schedules.
        request_example: >-
        {
        "query": {},
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "results": [
        {
        "schedule_id": "sch-3da9c9ed2ee2",
        "topic": "daily_cloud_service_summary",
        "state": "ENABLED",
        "options": {
        "aggregate": [
        {
        "query": {
        "query": {
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq",
        "value": true
        },
        {
        "key": "ref_cloud_service_type.labels",
        "value": "Server",
        "operator": "eq"
        }
        ]
        },
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Server"
        }
        }
        },
        {
        "concat": {
        "query": {
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary",
        "value": true
        },
        {
        "key": "ref_cloud_service_type.labels",
        "operator": "eq",
        "value": "Database"
        }
        ]
        },
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Database"
        }
        }
        },
        {
        "concat": {
        "query": {
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "operator": "eq",
        "value": true
        },
        {
        "operator": "eq",
        "value": "Container",
        "key": "ref_cloud_service_type.labels"
        }
        ]
        },
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Container"
        }
        }
        },
        {
        "concat": {
        "query": {
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "value": true,
        "operator": "eq"
        },
        {
        "key": "ref_cloud_service_type.labels",
        "operator": "eq",
        "value": "Networking"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "key": "project_id",
        "name": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ]
        }
        }
        ]
        },
        "extend_data": {
        "label": "Networking"
        },
        "resource_type": "inventory.CloudService"
        }
        },
        {
        "concat": {
        "extend_data": {
        "label": "Security"
        },
        "query": {
        "filter": [
        {
        "key": "ref_cloud_service_type.is_primary",
        "value": true,
        "operator": "eq"
        },
        {
        "key": "ref_cloud_service_type.labels",
        "value": "Security",
        "operator": "eq"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ],
        "fields": [
        {
        "operator": "count",
        "name": "value"
        }
        ]
        }
        }
        ]
        },
        "resource_type": "inventory.CloudService"
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "query": {
        "filter": [
        {
        "value": true,
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary"
        },
        {
        "key": "ref_cloud_service_type.labels",
        "operator": "eq",
        "value": "Analytics"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "name": "cloud_service_type",
        "key": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ]
        }
        }
        ]
        },
        "extend_data": {
        "label": "Analytics"
        }
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "query": {
        "aggregate": [
        {
        "group": {
        "fields": [
        {
        "name": "value",
        "operator": "count"
        }
        ],
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "key": "cloud_service_group",
        "name": "cloud_service_group"
        },
        {
        "name": "provider",
        "key": "provider"
        }
        ]
        }
        }
        ],
        "filter": [
        {
        "value": true,
        "operator": "eq",
        "key": "ref_cloud_service_type.is_primary"
        }
        ]
        },
        "extend_data": {
        "label": "All"
        }
        }
        },
        {
        "concat": {
        "resource_type": "inventory.CloudService",
        "extend_data": {
        "label": "Storage"
        },
        "query": {
        "filter": [
        {
        "key": "ref_cloud_service_type.is_major",
        "operator": "eq",
        "value": true
        },
        {
        "key": "ref_cloud_service_type.labels",
        "operator": "eq",
        "value": "Storage"
        }
        ],
        "aggregate": [
        {
        "group": {
        "keys": [
        {
        "name": "project_id",
        "key": "project_id"
        },
        {
        "key": "cloud_service_type",
        "name": "cloud_service_type"
        },
        {
        "name": "cloud_service_group",
        "key": "cloud_service_group"
        },
        {
        "key": "provider",
        "name": "provider"
        }
        ],
        "fields": [
        {
        "name": "value",
        "operator": "sum",
        "key": "data.size"
        }
        ]
        }
        }
        ]
        }
        }
        }
        ]
        },
        "schedule": {
        "hours": [
        1
        ]
        },
        "tags": {},
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-13T11:41:35.811Z"
        }
        ],
        "total_count": 1
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ScheduleServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'add': grpc.unary_unary_rpc_method_handler(
                    servicer.add,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.AddScheduleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.UpdateScheduleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.GetScheduleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.SchedulesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.statistics.v1.Schedule', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Schedule(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def add(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Schedule/add',
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.AddScheduleRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Schedule/update',
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.UpdateScheduleRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Schedule/enable',
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Schedule/disable',
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Schedule/delete',
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Schedule/get',
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.GetScheduleRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Schedule/list',
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleQuery.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.SchedulesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Schedule/stat',
            spaceone_dot_api_dot_statistics_dot_v1_dot_schedule__pb2.ScheduleStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/plugin/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/identity/plugin/auth.proto\x12\x1cspaceone.api.identity.plugin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"7\n\x0bInitRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"w\n\rVerifyRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x03 \x01(\t\"\x97\x01\n\x0b\x46indRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x0f\n\x07keyword\x18\x04 \x01(\t\x12\x0e\n\x06schema\x18\x05 \x01(\t\"\xa9\x01\n\x0cLoginRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x31\n\x10user_credentials\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x04 \x01(\t\"\xd4\x01\n\x08UserInfo\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06mobile\x18\x04 \x01(\t\x12\r\n\x05group\x18\x05 \x01(\t\x12;\n\x05state\x18\x06 \x01(\x0e\x32,.spaceone.api.identity.plugin.UserInfo.State\">\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x12\x10\n\x0cUNIDENTIFIED\x10\x03\"g\n\tUsersInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.identity.plugin.UserInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x12\x0c\n\x04more\x18\x03 \x01(\x08\":\n\x0e\x41uthVerifyInfo\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"7\n\nPluginInfo\x12)\n\x08metadata\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct2\xf3\x02\n\x04\x41uth\x12]\n\x04init\x12).spaceone.api.identity.plugin.InitRequest\x1a(.spaceone.api.identity.plugin.PluginInfo\"\x00\x12O\n\x06verify\x12+.spaceone.api.identity.plugin.VerifyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x04\x66ind\x12).spaceone.api.identity.plugin.FindRequest\x1a\'.spaceone.api.identity.plugin.UsersInfo\"\x00\x12]\n\x05login\x12*.spaceone.api.identity.plugin.LoginRequest\x1a&.spaceone.api.identity.plugin.UserInfo\"\x00\x62\x06proto3')



_INITREQUEST = DESCRIPTOR.message_types_by_name['InitRequest']
_VERIFYREQUEST = DESCRIPTOR.message_types_by_name['VerifyRequest']
_FINDREQUEST = DESCRIPTOR.message_types_by_name['FindRequest']
_LOGINREQUEST = DESCRIPTOR.message_types_by_name['LoginRequest']
_USERINFO = DESCRIPTOR.message_types_by_name['UserInfo']
_USERSINFO = DESCRIPTOR.message_types_by_name['UsersInfo']
_AUTHVERIFYINFO = DESCRIPTOR.message_types_by_name['AuthVerifyInfo']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_USERINFO_STATE = _USERINFO.enum_types_by_name['State']
InitRequest = _reflection.GeneratedProtocolMessageType('InitRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITREQUEST,
  '__module__' : 'spaceone.api.identity.plugin.auth_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.plugin.InitRequest)
  })
_sym_db.RegisterMessage(InitRequest)

VerifyRequest = _reflection.GeneratedProtocolMessageType('VerifyRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYREQUEST,
  '__module__' : 'spaceone.api.identity.plugin.auth_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.plugin.VerifyRequest)
  })
_sym_db.RegisterMessage(VerifyRequest)

FindRequest = _reflection.GeneratedProtocolMessageType('FindRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDREQUEST,
  '__module__' : 'spaceone.api.identity.plugin.auth_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.plugin.FindRequest)
  })
_sym_db.RegisterMessage(FindRequest)

LoginRequest = _reflection.GeneratedProtocolMessageType('LoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGINREQUEST,
  '__module__' : 'spaceone.api.identity.plugin.auth_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.plugin.LoginRequest)
  })
_sym_db.RegisterMessage(LoginRequest)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERINFO,
  '__module__' : 'spaceone.api.identity.plugin.auth_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.plugin.UserInfo)
  })
_sym_db.RegisterMessage(UserInfo)

UsersInfo = _reflection.GeneratedProtocolMessageType('UsersInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERSINFO,
  '__module__' : 'spaceone.api.identity.plugin.auth_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.plugin.UsersInfo)
  })
_sym_db.RegisterMessage(UsersInfo)

AuthVerifyInfo = _reflection.GeneratedProtocolMessageType('AuthVerifyInfo', (_message.Message,), {
  'DESCRIPTOR' : _AUTHVERIFYINFO,
  '__module__' : 'spaceone.api.identity.plugin.auth_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.plugin.AuthVerifyInfo)
  })
_sym_db.RegisterMessage(AuthVerifyInfo)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.identity.plugin.auth_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.plugin.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

_AUTH = DESCRIPTOR.services_by_name['Auth']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INITREQUEST._serialized_start=132
  _INITREQUEST._serialized_end=187
  _VERIFYREQUEST._serialized_start=189
  _VERIFYREQUEST._serialized_end=308
  _FINDREQUEST._serialized_start=311
  _FINDREQUEST._serialized_end=462
  _LOGINREQUEST._serialized_start=465
  _LOGINREQUEST._serialized_end=634
  _USERINFO._serialized_start=637
  _USERINFO._serialized_end=849
  _USERINFO_STATE._serialized_start=787
  _USERINFO_STATE._serialized_end=849
  _USERSINFO._serialized_start=851
  _USERSINFO._serialized_end=954
  _AUTHVERIFYINFO._serialized_start=956
  _AUTHVERIFYINFO._serialized_end=1014
  _PLUGININFO._serialized_start=1016
  _PLUGININFO._serialized_end=1071
  _AUTH._serialized_start=1074
  _AUTH._serialized_end=1445
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/price.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%spaceone/api/inventory/v1/price.proto\x12\x19spaceone.api.inventory.v1\x1a\x1cgoogle/api/annotations.proto\"\x97\x01\n\x0fGetPriceRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x15\n\rinstance_name\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x14\n\x0cservice_code\x18\x07 \x01(\t\x12\x15\n\rregional_type\x18\x0b \x01(\t\x12\x0f\n\x07\x64\x62_name\x18\x0c \x01(\t\x12\x0f\n\x07storage\x18\r \x01(\t\"\xf0\x01\n\x12GetPriceAltRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x15\n\rinstance_name\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\r\n\x05scale\x18\x04 \x01(\t\x12\x11\n\tsort_type\x18\x05 \x01(\t\x12\x32\n\x07\x66ilters\x18\x06 \x03(\x0b\x32!.spaceone.api.inventory.v1.Filter\x12\x14\n\x0cservice_code\x18\x07 \x01(\t\x12\x15\n\rregional_type\x18\x0b \x01(\t\x12\x0f\n\x07\x64\x62_name\x18\x0c \x01(\t\x12\x0f\n\x07storage\x18\r \x01(\t\")\n\x06\x46ilter\x12\t\n\x01k\x18\x01 \x01(\t\x12\t\n\x01o\x18\x02 \x01(\t\x12\t\n\x01v\x18\x03 \x01(\t\"m\n\x16\x43reatePriceInfoRequest\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\r\n\x05\x66orce\x18\x04 \x01(\x08\x12\x14\n\x0cservice_code\x18\x05 \x03(\t\"Q\n\x0c\x43reateResult\x12\x0e\n\x06result\x18\x01 \x01(\t\x12\x31\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32#.spaceone.api.inventory.v1.DataInfo\")\n\x08\x44\x61taInfo\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x11\"`\n\x0bProductInfo\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x0b\n\x03\x63pu\x18\x03 \x01(\x11\x12\x0e\n\x06memory\x18\x04 \x01(\t\x12\r\n\x05price\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\"\xb6\x02\n\x0c\x41ltPriceInfo\x12\x37\n\x07\x63urrent\x18\x01 \x01(\x0b\x32&.spaceone.api.inventory.v1.ProductInfo\x12;\n\x0b\x61lternative\x18\x02 \x01(\x0b\x32&.spaceone.api.inventory.v1.ProductInfo\x12\x39\n\x0e\x63urrent_prices\x18\x03 \x01(\x0b\x32!.spaceone.api.inventory.v1.Prices\x12=\n\x12\x61lternative_prices\x18\x04 \x01(\x0b\x32!.spaceone.api.inventory.v1.Prices\x12\x36\n\x0bprices_diff\x18\x05 \x01(\x0b\x32!.spaceone.api.inventory.v1.Prices\"P\n\x06Prices\x12\x16\n\x0eprice_per_hour\x18\x01 \x01(\x01\x12\x15\n\rprice_per_day\x18\x02 \x01(\x01\x12\x17\n\x0fprice_per_month\x18\x03 \x01(\x01\x32\x93\x03\n\x05Price\x12v\n\x03get\x12*.spaceone.api.inventory.v1.GetPriceRequest\x1a&.spaceone.api.inventory.v1.ProductInfo\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/inventory/v1/price\x12\x8a\x01\n\x0fget_alternative\x12-.spaceone.api.inventory.v1.GetPriceAltRequest\x1a\'.spaceone.api.inventory.v1.AltPriceInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/inventory/v1/price/alt\x12\x84\x01\n\x06\x63reate\x12\x31.spaceone.api.inventory.v1.CreatePriceInfoRequest\x1a\'.spaceone.api.inventory.v1.CreateResult\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/inventory/v1/productsb\x06proto3')



_GETPRICEREQUEST = DESCRIPTOR.message_types_by_name['GetPriceRequest']
_GETPRICEALTREQUEST = DESCRIPTOR.message_types_by_name['GetPriceAltRequest']
_FILTER = DESCRIPTOR.message_types_by_name['Filter']
_CREATEPRICEINFOREQUEST = DESCRIPTOR.message_types_by_name['CreatePriceInfoRequest']
_CREATERESULT = DESCRIPTOR.message_types_by_name['CreateResult']
_DATAINFO = DESCRIPTOR.message_types_by_name['DataInfo']
_PRODUCTINFO = DESCRIPTOR.message_types_by_name['ProductInfo']
_ALTPRICEINFO = DESCRIPTOR.message_types_by_name['AltPriceInfo']
_PRICES = DESCRIPTOR.message_types_by_name['Prices']
GetPriceRequest = _reflection.GeneratedProtocolMessageType('GetPriceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPRICEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetPriceRequest)
  })
_sym_db.RegisterMessage(GetPriceRequest)

GetPriceAltRequest = _reflection.GeneratedProtocolMessageType('GetPriceAltRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPRICEALTREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetPriceAltRequest)
  })
_sym_db.RegisterMessage(GetPriceAltRequest)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.Filter)
  })
_sym_db.RegisterMessage(Filter)

CreatePriceInfoRequest = _reflection.GeneratedProtocolMessageType('CreatePriceInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPRICEINFOREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreatePriceInfoRequest)
  })
_sym_db.RegisterMessage(CreatePriceInfoRequest)

CreateResult = _reflection.GeneratedProtocolMessageType('CreateResult', (_message.Message,), {
  'DESCRIPTOR' : _CREATERESULT,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateResult)
  })
_sym_db.RegisterMessage(CreateResult)

DataInfo = _reflection.GeneratedProtocolMessageType('DataInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATAINFO,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.DataInfo)
  })
_sym_db.RegisterMessage(DataInfo)

ProductInfo = _reflection.GeneratedProtocolMessageType('ProductInfo', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTINFO,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ProductInfo)
  })
_sym_db.RegisterMessage(ProductInfo)

AltPriceInfo = _reflection.GeneratedProtocolMessageType('AltPriceInfo', (_message.Message,), {
  'DESCRIPTOR' : _ALTPRICEINFO,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.AltPriceInfo)
  })
_sym_db.RegisterMessage(AltPriceInfo)

Prices = _reflection.GeneratedProtocolMessageType('Prices', (_message.Message,), {
  'DESCRIPTOR' : _PRICES,
  '__module__' : 'spaceone.api.inventory.v1.price_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.Prices)
  })
_sym_db.RegisterMessage(Prices)

_PRICE = DESCRIPTOR.services_by_name['Price']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRICE.methods_by_name['get']._options = None
  _PRICE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\025\022\023/inventory/v1/price'
  _PRICE.methods_by_name['get_alternative']._options = None
  _PRICE.methods_by_name['get_alternative']._serialized_options = b'\202\323\344\223\002\031\022\027/inventory/v1/price/alt'
  _PRICE.methods_by_name['create']._options = None
  _PRICE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\030\"\026/inventory/v1/products'
  _GETPRICEREQUEST._serialized_start=99
  _GETPRICEREQUEST._serialized_end=250
  _GETPRICEALTREQUEST._serialized_start=253
  _GETPRICEALTREQUEST._serialized_end=493
  _FILTER._serialized_start=495
  _FILTER._serialized_end=536
  _CREATEPRICEINFOREQUEST._serialized_start=538
  _CREATEPRICEINFOREQUEST._serialized_end=647
  _CREATERESULT._serialized_start=649
  _CREATERESULT._serialized_end=730
  _DATAINFO._serialized_start=732
  _DATAINFO._serialized_end=773
  _PRODUCTINFO._serialized_start=775
  _PRODUCTINFO._serialized_end=871
  _ALTPRICEINFO._serialized_start=874
  _ALTPRICEINFO._serialized_end=1184
  _PRICES._serialized_start=1186
  _PRICES._serialized_end=1266
  _PRICE._serialized_start=1269
  _PRICE._serialized_end=1672
# @@protoc_insertion_point(module_scope)
